@@ -19,13 +19,16 @@ from .metadata import (
 from .bigstore import (
     filter_smudge,
     filter_clean,
-    sync,
-    mkdir_p
+    init,
+    push,
+    pull,
 )
 
+import backends
+
 __all__ = [
     '__author__', '__copyright__', '__email__', '__license__',
     '__maintainer__', '__version__', 'filter_smudge', 'filter_clean',
-    'sync', 'mkdir_p'
+    'init', 'push', 'pull', 'backends'
 ]
 
